Class: DaytonaAnalyticsApiClient::ModelsLogEntry

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_analytics_api_client/models/models_log_entry.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ModelsLogEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaAnalyticsApiClient::ModelsLogEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaAnalyticsApiClient::ModelsLogEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'log_attributes')
    if (value = attributes[:'log_attributes']).is_a?(Hash)
      self.log_attributes = value
    end
  end

  if attributes.key?(:'resource_attributes')
    if (value = attributes[:'resource_attributes']).is_a?(Hash)
      self.resource_attributes = value
    end
  end

  if attributes.key?(:'service_name')
    self.service_name = attributes[:'service_name']
  end

  if attributes.key?(:'severity_number')
    self.severity_number = attributes[:'severity_number']
  end

  if attributes.key?(:'severity_text')
    self.severity_text = attributes[:'severity_text']
  end

  if attributes.key?(:'span_id')
    self.span_id = attributes[:'span_id']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'trace_id')
    self.trace_id = attributes[:'trace_id']
  end
end

Instance Attribute Details

#bodyObject

Returns the value of attribute body.



18
19
20
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 18

def body
  @body
end

#log_attributesObject

Returns the value of attribute log_attributes.



20
21
22
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 20

def log_attributes
  @log_attributes
end

#resource_attributesObject

Returns the value of attribute resource_attributes.



22
23
24
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 22

def resource_attributes
  @resource_attributes
end

#service_nameObject

Returns the value of attribute service_name.



24
25
26
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 24

def service_name
  @service_name
end

#severity_numberObject

Returns the value of attribute severity_number.



26
27
28
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 26

def severity_number
  @severity_number
end

#severity_textObject

Returns the value of attribute severity_text.



28
29
30
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 28

def severity_text
  @severity_text
end

#span_idObject

Returns the value of attribute span_id.



30
31
32
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 30

def span_id
  @span_id
end

#timestampObject

Returns the value of attribute timestamp.



32
33
34
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 32

def timestamp
  @timestamp
end

#trace_idObject

Returns the value of attribute trace_id.



34
35
36
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 34

def trace_id
  @trace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 37

def self.attribute_map
  {
    :'body' => :'body',
    :'log_attributes' => :'logAttributes',
    :'resource_attributes' => :'resourceAttributes',
    :'service_name' => :'serviceName',
    :'severity_number' => :'severityNumber',
    :'severity_text' => :'severityText',
    :'span_id' => :'spanId',
    :'timestamp' => :'timestamp',
    :'trace_id' => :'traceId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 185

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 62

def self.openapi_types
  {
    :'body' => :'String',
    :'log_attributes' => :'Hash<String, String>',
    :'resource_attributes' => :'Hash<String, String>',
    :'service_name' => :'String',
    :'severity_number' => :'Integer',
    :'severity_text' => :'String',
    :'span_id' => :'String',
    :'timestamp' => :'String',
    :'trace_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 156

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      body == o.body &&
      log_attributes == o.log_attributes &&
      resource_attributes == o.resource_attributes &&
      service_name == o.service_name &&
      severity_number == o.severity_number &&
      severity_text == o.severity_text &&
      span_id == o.span_id &&
      timestamp == o.timestamp &&
      trace_id == o.trace_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


172
173
174
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 172

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



178
179
180
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 178

def hash
  [body, log_attributes, resource_attributes, service_name, severity_number, severity_text, span_id, timestamp, trace_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 207

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



149
150
151
152
# File 'lib/daytona_analytics_api_client/models/models_log_entry.rb', line 149

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end