Class: DaytonaAnalyticsApiClient::ModelsSandboxUsage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaAnalyticsApiClient::ModelsSandboxUsage
- Defined in:
- lib/daytona_analytics_api_client/models/models_sandbox_usage.rb
Instance Attribute Summary collapse
-
#first_start ⇒ Object
Returns the value of attribute first_start.
-
#last_end ⇒ Object
Returns the value of attribute last_end.
-
#sandbox_id ⇒ Object
Returns the value of attribute sandbox_id.
-
#total_cpu_seconds ⇒ Object
Returns the value of attribute total_cpu_seconds.
-
#total_disk_gb_seconds ⇒ Object
Returns the value of attribute total_disk_gb_seconds.
-
#total_gpu_seconds ⇒ Object
Returns the value of attribute total_gpu_seconds.
-
#total_price ⇒ Object
Returns the value of attribute total_price.
-
#total_ramgb_seconds ⇒ Object
Returns the value of attribute total_ramgb_seconds.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelsSandboxUsage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ModelsSandboxUsage
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaAnalyticsApiClient::ModelsSandboxUsage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaAnalyticsApiClient::ModelsSandboxUsage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'first_start') self.first_start = attributes[:'first_start'] end if attributes.key?(:'last_end') self.last_end = attributes[:'last_end'] end if attributes.key?(:'sandbox_id') self.sandbox_id = attributes[:'sandbox_id'] end if attributes.key?(:'total_cpu_seconds') self.total_cpu_seconds = attributes[:'total_cpu_seconds'] end if attributes.key?(:'total_disk_gb_seconds') self.total_disk_gb_seconds = attributes[:'total_disk_gb_seconds'] end if attributes.key?(:'total_gpu_seconds') self.total_gpu_seconds = attributes[:'total_gpu_seconds'] end if attributes.key?(:'total_price') self.total_price = attributes[:'total_price'] end if attributes.key?(:'total_ramgb_seconds') self.total_ramgb_seconds = attributes[:'total_ramgb_seconds'] end end |
Instance Attribute Details
#first_start ⇒ Object
Returns the value of attribute first_start.
18 19 20 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 18 def first_start @first_start end |
#last_end ⇒ Object
Returns the value of attribute last_end.
20 21 22 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 20 def last_end @last_end end |
#sandbox_id ⇒ Object
Returns the value of attribute sandbox_id.
22 23 24 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 22 def sandbox_id @sandbox_id end |
#total_cpu_seconds ⇒ Object
Returns the value of attribute total_cpu_seconds.
24 25 26 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 24 def total_cpu_seconds @total_cpu_seconds end |
#total_disk_gb_seconds ⇒ Object
Returns the value of attribute total_disk_gb_seconds.
26 27 28 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 26 def total_disk_gb_seconds @total_disk_gb_seconds end |
#total_gpu_seconds ⇒ Object
Returns the value of attribute total_gpu_seconds.
28 29 30 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 28 def total_gpu_seconds @total_gpu_seconds end |
#total_price ⇒ Object
Returns the value of attribute total_price.
30 31 32 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 30 def total_price @total_price end |
#total_ramgb_seconds ⇒ Object
Returns the value of attribute total_ramgb_seconds.
32 33 34 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 32 def total_ramgb_seconds @total_ramgb_seconds end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 35 def self.attribute_map { :'first_start' => :'firstStart', :'last_end' => :'lastEnd', :'sandbox_id' => :'sandboxId', :'total_cpu_seconds' => :'totalCPUSeconds', :'total_disk_gb_seconds' => :'totalDiskGBSeconds', :'total_gpu_seconds' => :'totalGPUSeconds', :'total_price' => :'totalPrice', :'total_ramgb_seconds' => :'totalRAMGBSeconds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 59 def self.openapi_types { :'first_start' => :'String', :'last_end' => :'String', :'sandbox_id' => :'String', :'total_cpu_seconds' => :'Integer', :'total_disk_gb_seconds' => :'Integer', :'total_gpu_seconds' => :'Integer', :'total_price' => :'Float', :'total_ramgb_seconds' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && first_start == o.first_start && last_end == o.last_end && sandbox_id == o.sandbox_id && total_cpu_seconds == o.total_cpu_seconds && total_disk_gb_seconds == o.total_disk_gb_seconds && total_gpu_seconds == o.total_gpu_seconds && total_price == o.total_price && total_ramgb_seconds == o.total_ramgb_seconds end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 165 def hash [first_start, last_end, sandbox_id, total_cpu_seconds, total_disk_gb_seconds, total_gpu_seconds, total_price, total_ramgb_seconds].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 |
# File 'lib/daytona_analytics_api_client/models/models_sandbox_usage.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |