Class: DaytonaAnalyticsApiClient::ModelsSpan

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_analytics_api_client/models/models_span.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ModelsSpan

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaAnalyticsApiClient::ModelsSpan` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaAnalyticsApiClient::ModelsSpan`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'duration_ms')
    self.duration_ms = attributes[:'duration_ms']
  end

  if attributes.key?(:'parent_span_id')
    self.parent_span_id = attributes[:'parent_span_id']
  end

  if attributes.key?(:'span_attributes')
    if (value = attributes[:'span_attributes']).is_a?(Hash)
      self.span_attributes = value
    end
  end

  if attributes.key?(:'span_id')
    self.span_id = attributes[:'span_id']
  end

  if attributes.key?(:'span_name')
    self.span_name = attributes[:'span_name']
  end

  if attributes.key?(:'status_code')
    self.status_code = attributes[:'status_code']
  end

  if attributes.key?(:'status_message')
    self.status_message = attributes[:'status_message']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'trace_id')
    self.trace_id = attributes[:'trace_id']
  end
end

Instance Attribute Details

#duration_msObject

Returns the value of attribute duration_ms.



18
19
20
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 18

def duration_ms
  @duration_ms
end

#parent_span_idObject

Returns the value of attribute parent_span_id.



20
21
22
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 20

def parent_span_id
  @parent_span_id
end

#span_attributesObject

Returns the value of attribute span_attributes.



22
23
24
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 22

def span_attributes
  @span_attributes
end

#span_idObject

Returns the value of attribute span_id.



24
25
26
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 24

def span_id
  @span_id
end

#span_nameObject

Returns the value of attribute span_name.



26
27
28
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 26

def span_name
  @span_name
end

#status_codeObject

Returns the value of attribute status_code.



28
29
30
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 28

def status_code
  @status_code
end

#status_messageObject

Returns the value of attribute status_message.



30
31
32
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 30

def status_message
  @status_message
end

#timestampObject

Returns the value of attribute timestamp.



32
33
34
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 32

def timestamp
  @timestamp
end

#trace_idObject

Returns the value of attribute trace_id.



34
35
36
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 34

def trace_id
  @trace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 37

def self.attribute_map
  {
    :'duration_ms' => :'durationMs',
    :'parent_span_id' => :'parentSpanId',
    :'span_attributes' => :'spanAttributes',
    :'span_id' => :'spanId',
    :'span_name' => :'spanName',
    :'status_code' => :'statusCode',
    :'status_message' => :'statusMessage',
    :'timestamp' => :'timestamp',
    :'trace_id' => :'traceId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 183

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 62

def self.openapi_types
  {
    :'duration_ms' => :'Float',
    :'parent_span_id' => :'String',
    :'span_attributes' => :'Hash<String, String>',
    :'span_id' => :'String',
    :'span_name' => :'String',
    :'status_code' => :'String',
    :'status_message' => :'String',
    :'timestamp' => :'String',
    :'trace_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 154

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      duration_ms == o.duration_ms &&
      parent_span_id == o.parent_span_id &&
      span_attributes == o.span_attributes &&
      span_id == o.span_id &&
      span_name == o.span_name &&
      status_code == o.status_code &&
      status_message == o.status_message &&
      timestamp == o.timestamp &&
      trace_id == o.trace_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


170
171
172
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 170

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



176
177
178
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 176

def hash
  [duration_ms, parent_span_id, span_attributes, span_id, span_name, status_code, status_message, timestamp, trace_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
143
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 139

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
# File 'lib/daytona_analytics_api_client/models/models_span.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end